#!/bin/bash

PWDIR=`pwd`
if [ `id|grep -c "root"` -eq 0 ]; then
	echo "rootで実行してください"
	exit
fi

source ./EpgRec_inst.conf || exit

if [ ! -d files ]; then
	mkdir files
fi

# EpgRecのインストール
if [ ! -f files/epgrec-20100322.tar.gz ]; then
	cd files
	wget http://www.sky.sannet.ne.jp/kn_ishi/epgrec/files/epgrec-20100322.tar.gz
	cd ..
fi
echo
tar xvzpf files/epgrec-20100322.tar.gz -C /var/www/

if [ ! -f files/epgrec-20100322fix1.tar.gz ]; then
	cd files
	wget http://www.sky.sannet.ne.jp/kn_ishi/epgrec/files/epgrec-20100322fix1.tar.gz
	cd ..
fi
echo
tar -zxvf files/epgrec-20100322fix1.tar.gz -C ${PWDIR}
cd /var/www/epgrec && cat ${PWDIR}/epgrec-20100322fix1.diff | patch -p1 && chown 1000 *
cd ${PWDIR} && rm epgrec-20100322fix1.diff readme.txt


# 実行中の録画の停止化(旧バージョンへ戻す)とログの修正
if [ ! -f files/epgrec-20100322fix1fix.tar.gz ]; then
	cd files
	wget http://www.sky.sannet.ne.jp/kn_ishi/epgrec/files/epgrec-20100322fix1fix.tar.gz
	cd ..
fi
echo
tar -zxvf files/epgrec-20100322fix1fix.tar.gz -C ${PWDIR}
cd /var/www/epgrec && cat ${PWDIR}/epgrec-20100322fix1fix.diff | patch -p1 && chown 1000 *
cd ${PWDIR} && rm epgrec-20100322fix1fix.diff readme.txt

# 録画アルゴリズムの改善
if [ ! -f files/Reservation.class_20110220kn.tar.gz ]; then
	cd files
	wget http://www.sky.sannet.ne.jp/kn_ishi/epgrec/files/Reservation.class_20110220kn.tar.gz
	cd ..
fi
echo
tar -zxvf files/Reservation.class_20110220kn.tar.gz -C ${PWDIR}
cd /var/www/epgrec && cat ${PWDIR}/Reservation.class_20110220kn.diff | patch -p1 && chown 1000 *
cd ${PWDIR} && rm Reservation.class_20110220kn.diff readme.txt

# 各ページの表示のカスタマイズ
if [ ! -f files/epgrec-templates_ken.tar.gz ]; then
	cd files
	wget http://www.sky.sannet.ne.jp/kn_ishi/epgrec/files/epgrec-templates_ken.tar.gz
	cd ..
fi
echo
tar -zxvf files/epgrec-templates_ken.tar.gz -C ${PWDIR}
cd /var/www/epgrec && cat ${PWDIR}/epgrec-templates_ken.diff | patch -p1 && chown 1000 templates/*
cd ${PWDIR} && rm epgrec-templates_ken.diff readme.txt

# ファイル名にあると面倒な文字列の変換とチャンネル表示の変更
if [ ! -f files/Reservation.class_20111120kn.diff.gz ]; then
	cd files
	wget http://www.sky.sannet.ne.jp/kn_ishi/epgrec/files/Reservation.class_20111120kn.diff.gz
	cd ..
fi
echo
cp -p files/Reservation.class_20111120kn.diff.gz . || exit
gunzip -v Reservation.class_20111120kn.diff.gz
cd /var/www/epgrec && cat ${PWDIR}/Reservation.class_20111120kn.diff | patch -p1 && chown 1000 *
cd ${PWDIR} && rm Reservation.class_20111120kn.diff


# apache2の設定 /etc/apache2/sites-available/default
#---------------------------------------------------
IFS=$'\n'
ORG="/etc/apache2/sites-available/default.org"
OUT="/etc/apache2/sites-available/default"
cp -p ${OUT} ${ORG}
echo -n > ${OUT}
while read -r line; do
	if [ `echo "${line}"|grep -c "DocumentRoot /var/www$"` -ne 0 ]; then
		echo -e "\tDocumentRoot /var/www/epgrec" >> ${OUT}
		read -r line
		echo -e "\t<Directory /var/www/epgrec>" >> ${OUT}
		read -r line
		echo "${line}" >> ${OUT}
		read -r line
		echo "${line}" >> ${OUT}
		echo -e "\t\tOrder allow,deny" >> ${OUT}
		echo -e "\t\tAllow from 192.168.11. localhost" >> ${OUT}
		echo -e "\t\tDirectoryIndex index.html index.html.var index.php" >> ${OUT}
	else
		echo "${line}" >> ${OUT}
	fi
done < ${ORG}


# 受信チャンネルの設定 /var/www/epgrec/config.php
#------------------------------------------------
IFS=$'\n'
ORG="/var/www/epgrec/config.php.sample"
OUT="/var/www/epgrec/config.php"
echo -n > ${OUT}
while read -r line; do
	if [ `echo "${line}"|grep -c "首都圏用地上デジタルチャンネルマップ"` -ne 0 ]; then
		echo "${line}"	>> ${OUT}
		read -r line
		echo "${line}"	>> ${OUT}
		echo '$GR_CHANNEL_MAP = array('			>> ${OUT}
		cat GR_CHANNELS.conf				>> ${OUT}
		echo ');'					>> ${OUT}
		echo						>> ${OUT}
		echo						>> ${OUT}
		while [ `echo "${line}"|grep -c '// 録画モード（option）'` -eq 0 ]; do
			read -r line
		done
		echo "${line}" >> ${OUT}
	else
		if [ `echo "${line}"|grep -c 'define( "PADDING_TIME"'` -ne 0 ]; then
			echo 'define( "PADDING_TIME", 0 );					// 詰め物時間'	>> ${OUT}
		else
			echo "${line}" >> ${OUT}
		fi
	fi
done < ${ORG}
chown 1000 ${OUT}
chgrp 1000 ${OUT}
chmod 755 ${OUT}


# 録画実行用スクリプトの準備
cp --archive /var/www/epgrec/do-record.sh.pt1 /var/www/epgrec/do-record.sh


# EpgRecの設定
OUT="/var/www/epgrec/settings/config.xml"
echo '<?xml version="1.0" encoding="UTF-8"?>'										> ${OUT}
echo -n '<epgrec><spool>/video</spool><thumbs>/thumbs</thumbs><install_url>http://'${IP_ADDRESS}'</install_url>'	>> ${OUT}
echo -n '<bs_tuners>'${BS_TUNERS}'</bs_tuners><gr_tuners>'${GR_TUNERS}'</gr_tuners>'					>> ${OUT}
echo -n '<cs_rec_flg>'${CS_REC_FLG}'</cs_rec_flg><use_kurobon>'${USE_KUROBON}'</use_kurobon>'				>> ${OUT}
echo -n '<former_time>'${FORMER_TIME}'</former_time><extra_time>'${EXTRA_TIME}'</extra_time>'				>> ${OUT}
echo -n '<force_cont_rec>'${FORCE_CONT_REC}'</force_cont_rec><rec_switch_time>'${REC_SWITCH_TIME}'</rec_switch_time>'	>> ${OUT}
echo -n '<use_thumbs>0</use_thumbs><mediatomb_update>0</mediatomb_update>'						>> ${OUT}
echo -n '<filename_format>'${FILENAME_FORMAT}'</filename_format><db_host>'${DB_HOST}'</db_host>'			>> ${OUT}
echo -n '<db_name>'${MySQL_DB}'</db_name><db_user>'${MySQL_USER}'</db_user><db_pass>'${MySQL_PSWD}'</db_pass>'		>> ${OUT}
echo -n '<tbl_prefix>Recorder_</tbl_prefix><epgdump>/usr/local/bin/epgdump</epgdump><at>/usr/bin/at</at>'		>> ${OUT}
echo -n '<atrm>/usr/bin/atrm</atrm><sleep>/bin/sleep</sleep><ffmpeg>/usr/bin/ffmpeg</ffmpeg>'				>> ${OUT}
echo -n '<temp_data>/tmp/__temp.ts</temp_data><temp_xml>/tmp/__temp.xml</temp_xml>'					>> ${OUT}
echo -n '<program_length>'${PROGRAM_LENGTH}'</program_length><ch_set_width>'${CH_SET_WIDTH}'</ch_set_width>'		>> ${OUT}
echo    '<height_per_hour>'${HEIGHT_PER_HOUER}'</height_per_hour><autorec_mode>0</autorec_mode></epgrec>'		>> ${OUT}
chown www-data ${OUT}
chgrp www-data ${OUT}


# filemanage.shの準備
#--------------------
if [ ! -d /var/www/scr ]; then
	mkdir -m 777 /var/www/scr
fi
OUT="/var/www/scr/filemanage.sh"
cat <<'EOF' > ${OUT}
#!/bin/bash
#
# filemanage.sh 2010.08.29
# ディスク使用率がLIMIT以上になったら
# 古い順に録画ファイルを自動的に削除する。
#

ii=0
jj=0
while [ $ii -lt 10 ]; do
  jj=$((jj+`ps -A r|grep -c "mplayer"`))
  ii=$((ii+1))
  sleep 0.05
done
if [ $jj -ne 0 ]; then
  #echo "Mplayer is running!!" > filemanage.log
  exit
fi

LIM=95
EPGRECHOME="/var/www/epgrec"
CONF=`grep '<spool>' ${EPGRECHOME}/settings/config.xml`

# 設定ファイルから録画pathを取得する→DFPATH
DFPATH=${EPGRECHOME}`expr ${CONF} : '.*<spool>\(.*\)</spool>'`

# 現在のディスク使用率を取得する→$NOW
NOW=`df ${DFPATH}|tail -1|awk '{print $(NF-1)}'|sed s/%//`

# ディスク使用率がLIMIT以上ならループに入る
while [ $NOW -ge $LIM ]; do

  # 一番古いファイルを削除する
  FILEFULL=`ls -1rt /var/www/epgrec/video/*.ts|head -1`
  rm -f ${FILEFULL}

  # データベースからデータを削除する
  FILE=\"`basename \"${FILEFULL}\"`

  echo 'use epgrec;' >sqlcmd
  echo -n 'delete from Recorder_reserveTbl where complete=1 and path=' >>sqlcmd
  echo "${FILE};" >>sqlcmd
EOF

echo '  mysql --user='${MySQL_USER}' --password='${MySQL_PSWD}' <sqlcmd'	>> ${OUT}

cat <<'EOF' >> ${OUT}

  # ディスク使用率を取得する
  NOW=`df ${DFPATH}|tail -1|awk '{print $(NF-1)}'|sed s/%//`

done
EOF

chown 1000 ${OUT}
chgrp 1000 ${OUT}
chmod +x ${OUT}


# cronファイルの作成
#-------------------
OUT="/etc/cron.d/getepg"
cat <<'EOF' > ${OUT}
SHELL=/bin/sh
PATH=/usr/local/sbin:/usr/local/bin:/sbin:/bin:/usr/sbin:/usr/bin

29 6-22/2 * * *   www-data      /var/www/epgrec/getepg.php
00 2-6    * * *   root          /var/www/scr/filemanage.sh
EOF
chmod 644 ${OUT}


# recbymail
#========================
apt-get install php-pear
pear channel-update pear.php.net
pear install Auth_SASL
pear install Net_POP3
pear install Net_SMTP
pear install Mail
pear install Mail_Mime

if [ ! -d /var/www/scr ]; then
	mkdir -m 777 /var/www/scr
fi
if [ ! -d /var/www/scr/recbymail ]; then
	mkdir -m 777 /var/www/scr/recbymail
fi
if [ ! -f files/recbymail.tar.gz ]; then
	cd files
	wget http://www.sky.sannet.ne.jp/kn_ishi/epgrec/files/recbymail.tar.gz
	cd ..
fi
echo
tar -zxvf files/recbymail.tar.gz -C /var/www/scr/recbymail

OUT="/var/www/scr/recbymail/recbymail.config.php"
cat <<'EOF' > ${OUT}
<?php

define("DEBUGSW","off");

//このシステムの日本語エンコーディングを設定する
mb_language("japanese");
$sysencoding=mb_detect_encoding("このシステムの日本語エンコーディングを取得する",mb_list_encodings());
mb_internal_encoding($sysencoding);

EOF

cat RECBYMAIL.conf >> ${OUT}

cat <<'EOF' >> ${OUT}

define("RPC_TYPE", 1);

?>
EOF
chown 1000 ${OUT}
chgrp 1000 ${OUT}
chmod 755 ${OUT}

OUT="/etc/cron.d/getepg"
cat <<'EOF' >> ${OUT}
*/5 *     * * *   www-data      /var/www/scr/recbymail/recbymail.php
EOF


cd ${PWDIR}
rm GR_CHANNELS.conf
rm RECBYMAIL.conf


echo
echo "EpgRecのインストール完了"
echo "recbymailのインストール完了"
echo "次は再生環境の構築です"
echo "4_DLNA_SMplayer.sh"
echo

